function [axfnt, txfnt] = fig_defs( varargin )

%
%     fig_defs
%     fig_defs(height)
%     fig_defs(height, width)
%     fig_defs(height, width, ...)
%     fig_defs(...)
%
%     Set defaults for dissertation figures
%
%     defaults:  height = 0.4 \textheight ~  8.75 cm
%                width  =     \textwidth  = 16.2  cm
%
%     ... can be key-value pairs 'height', xxx / 'width', xxx
%             or switches 'b/w', 'color'
%                         'mild', 'sharp' for color map selection
%             'fullpage'    full portrait page (wd 16.2, ht 19.5)
%             'fullland'    full page for sidewaysfig (wd 22.0, ht 13.0)
%             'onetop'      one 'flat' figure on top of page
%             'twotop'      two figures side-by-side on top of page
%             'talltop'     'tall' figure on top of page
%             'fullfoil'    transparency
%             'foil'        turns on color, larger labels ...
%
%             or figure object properties that are passed to set(gcf,...)
%

%   Copyright (C) 2001 Hans Ekkehard Plesser
%
%   This program is free software; you can redistribute it and/or
%   modify it under the terms of the GNU General Public License
%   as published by the Free Software Foundation; either version 2
%   of the License, or (at your option) any later version.
%
%   This program is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   GNU General Public License for more details.
%
%   You should have received a copy of the GNU General Public License
%   along with this program; if not, write to the Free Software
%   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

% clear figure
clf

% figure size, defaults first
width  = 15.5;          % cm
height =    8;          % cm
color  =    0;          % no color
mildmap=    1;
axfntsz=   10;
txfntsz=   10;
axlnwd =    1;
lnlnwd =    1;

% default tick length
ticklen = [0.01 0.015];

n_in = length(varargin);    % actual number of arguments

% check for numbers at the beginning
beg_list = 1;
if n_in >= 1,
  if isnumeric(varargin{1})
    height = varargin{1};
    beg_list = beg_list + 1;
    if n_in >=2,
      if isnumeric(varargin{2}),
	width = varargin{2};
	beg_list = beg_list + 1;
      end
    end
  end
end

% handle remaining input
j = beg_list;
prop_ctr = 0;
while j <= n_in,
  switch varargin{j},
    case 'onetop',   height =  8.0; width = 14.0;  % narrow for proportions
    case 'twotop',   height =  7.0; width = 15.5;
                     ticklen = [0.02 0.02];
    case 'talltop',  height = 12.5; width = 15.5;
                     ticklen = [0.01 0.03];
    case 'fullpage', height = 19.5; width = 15.5;
                     ticklen = [0.01 0.015];
    case 'fullland', height = 13.0; width = 25.0;  % extra wide, so final ok
    case 'fullfoil', height = 18.0; width = 15.5;  % extra wide, so final ok
    case 'height', height = varargin{j+1}; j = j+1; 
    case 'width',  width  = varargin{j+1}; j = j+1; 
    case 'ticklen',  ticklen  = varargin{j+1}*[1 1]; j = j+1; 
    case 'b/w',    color  = 0;   
    case 'color',  color  = 1;  
    case 'sharp',  mildmap= 0;  
    case 'foil',  color=1; axfntsz=16; txfntsz=16; axlnwd=2; lnlnwd=2.5;
    otherwise % pass name-value pair on to set
      prop_ctr = prop_ctr + 1;
      prop_name(prop_ctr) = {varargin{j}};
      prop_val(prop_ctr)  = {varargin{j+1}}; j = j+1;
  end
  j = j+1;
end

% standard stuff first

% figure size
set(gcf, 'PaperUnits', 'centimeter')
set(gcf, 'PaperPosition', [0, 0, width, height])

% axes and legend font size and name
set(gcf, 'DefaultAxesFontSize', axfntsz);
set(gcf, 'DefaultTextFontSize', txfntsz);
set(gcf, 'DefaultAxesFontName', 'Helvetica');
set(gcf, 'DefaultTextFontName', 'Helvetica');

% tick length
set(gcf, 'DefaultAxesTickLength', ticklen);

% axes on top 
set(gcf,'DefaultAxesLayer','top');

% line width, marker size
set(gcf, 'DefaultAxesLineWidth',  axlnwd);
set(gcf, 'DefaultLineLineWidth',  lnlnwd);
set(gcf, 'DefaultLineMarkerSize', 8);

% save a lot of time, disk space ...
set(gcf,'DefaultSurfaceFaceColor','flat')

% black-and-white or color figures?
if color,
  set(gcf, 'DefaultAxesColorOrder', ...
          [1.00 0.00 0.00 ; ...   % red
	   0.00 0.00 1.00 ; ...   % blue
	   1.00 0.78 0.00 ; ...   % yellow
           0.37 0.98 0.09 ; ...   % bright green
	   0.60 0.30 0.00 ; ...   % brown
	   0.00 1.00 1.00 ; ...   % cyan
           1.00 0.63 0.63 ; ...   % pink
	   0.00 0.66 0.00 ; ...   % dark green
	   0.83 0.63 0.09 ; ...   % sand
	   0.50 0.50 0.50   ...   % grey
	  ]);
  set(gcf, 'DefaultAxesLineStyleOrder', '-');

  cm = jet(256);
  if mildmap,
    colormap(cm(1:200, :));
  else
    colormap(cm);
  end
else
  % just black
  set(gcf, 'DefaultAxesColorOrder', [0 0 0]);
  set(gcf, 'DefaultAxesLineStyleOrder', '-|-.|--|:')
  
  % no shading, greyscale color map skipping whitest tones
  cm = bone(256);
  colormap(cm(256:-1:50, :));
end

% now pass remaining property-value pairs
if exist('prop_name') & exist('prop_val'),
  set(gcf, prop_name, prop_val);
end

return