function tex_htable(tabfile, tabfmt, tab),

%    tex_htable(tabfile, tab)
%
%  creates a LaTeX-File containing a table presenting matrix data
%  the table is organized horizontally
%
%  tabfile     output file, '.tex' is appended
%  tabfmt      struct 
%                      .format    'int', 'fix', 'sci'
%                      .digits    (mantissa) digits right of dec.pt.
%  tab         struct array, one struct per row
%                tab(j).header    string with table head, math
%                      .data      vector with row data
%                      [.error]   vector with error data, shown as
%                                       data +- error, only sci
%
%  The LaTeX created requires class diss.

%   Copyright (C) 2001 Hans Ekkehard Plesser
%
%   This program is free software; you can redistribute it and/or
%   modify it under the terms of the GNU General Public License
%   as published by the Free Software Foundation; either version 2
%   of the License, or (at your option) any later version.
%
%   This program is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   GNU General Public License for more details.
%
%   You should have received a copy of the GNU General Public License
%   along with this program; if not, write to the Free Software
%   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.


% get number of columns and rows
nrows = length(tab);
ncols = -1;
for j = 1:nrows,
  ncols = max([length(tab(j).data) ncols]);
end

err = zeros(nrows, 1);
if isfield(tab, 'error'),
  for j = 1:nrows,
    err(j) = prod(size(tab(j).error));  % check if row has errors
  end
end

% open file and write tabular header
tabout = fopen([tabfile '.tex'], 'w');

% set tabular parameters, encapsule table in {}
fprintf(tabout, '{%%  Table generated by tex_htable.m\n%%\n');
fprintf(tabout, '\\setlength{\\extrarowheight}{2pt}\n');
fprintf(tabout, '\\setlength{\\arrayrulewidth}{0.4pt}\n');
fprintf(tabout, '\\setlength{\\doublerulesep}{0pt}\n');
fprintf(tabout, '\\setlength{\\tabcolsep}{6pt}\n');
fprintf(tabout, '\\renewcommand{\\arraystretch}{1.05}\n%%\n');

fprintf(tabout, '\\begin{tabular}{L');
switch tabfmt.format
  case 'int'
    fprintf(tabout, '*{%d}R', ncols);
  case 'fix'
    fprintf(tabout, '*{%d}{D{.}{.}{%d}}', ncols, tabfmt.digits); 
  case 'sci'
    fprintf(tabout, '*{%d}{R@{$\\cdot$}L}', ncols, tabfmt.digits);
               % mantissa fix, central dot, exponent
  otherwise
    fclose(tabout);	       
    error(['Unknown format: ' tabfmt.format ' !']);
end
fprintf(tabout, '}\n');
    
% table data
fprintf(tabout, '  \\hline\\hline\n');
for r = 1:nrows,

  fprintf(tabout, '  %s & \n', tab(r).header);
  
  for j = 1:ncols,
    switch tabfmt.format
      case 'int'
	if j <= length(tab(r).data),
	  if isfinite(tab(r).data(j)),
	    fprintf(tabout, '%10.0f', fix(tab(r).data(j)));
	  elseif isinf(tab(r).data(j)),
	    if tab(r).data(j) > 0,
	      fprintf(tabout, '\\multicolumn{1}{C}{+\\infty}');
	    else
	      fprintf(tabout, '\\multicolumn{1}{C}{-\\infty}');
	    end
	  else
	    fprintf(tabout, '%10s', ' ');      % NAN
	  end
	else
	  fprintf(tabout, '%10s', ' ');
	end
      case 'fix'
	if j <= length(tab(r).data),
	  if isfinite(tab(r).data(j)),
	    fprintf(tabout, ['%10.' num2str(tabfmt.digits) 'f'], ...
		            tab(r).data(j));
	  elseif isinf(tab(r).data(j)),
	    if tab(r).data(j) > 0,
	      fprintf(tabout, '\\multicolumn{1}{C}{+\\infty}');
	    else
	      fprintf(tabout, '\\multicolumn{1}{C}{-\\infty}');
	    end
	  else
	    fprintf(tabout, '%10s', ' ');      % NAN
	  end
	else
	  fprintf(tabout, '%10s', ' ');
	end
      case 'sci'
	if j <= length(tab(r).data),
	  if isfinite(tab(r).data(j)),
	    if tab(r).data(j) ~= 0,
	      ex   = floor(log10(abs(tab(r).data(j))));
	      mant = tab(r).data(j) / 10^ex;
	      if err(r) & tab(r).error(j) ~= 0,
		manterr = tab(r).error(j) / 10^ex;
		if tab(r).error(j) > 0
		  fprintf(tabout, ['(%10.' num2str(tabfmt.digits) ...
			           'f \\pm %10.' num2str(tabfmt.digits) ...
			           'f) & 10^{%-2d}'], ...
		                  mant, manterr, ex);
		else
		  fprintf(tabout, ['(%10.' num2str(tabfmt.digits) ...
			           'f \\mp %10.' num2str(tabfmt.digits) ...
				   'f) & 10^{%-2d}'], ...
	                          mant, -manterr, ex);
		end	    
              else
	        fprintf(tabout, ...
	                  ['%10.' num2str(tabfmt.digits) 'f & 10^{%-2d}'], ...
	                  mant, ex);
              end
	    else	    
	      fprintf(tabout, '\\multicolumn{2}{C}{0}');
	    end  
	  elseif isinf(tab(r).data(j)),
	    if tab(r).data(j) > 0,
	      fprintf(tabout, '\\multicolumn{2}{C}{+\\infty}');
	    else
	      fprintf(tabout, '\\multicolumn{2}{C}{-\\infty}');
	    end
	  else
	    fprintf(tabout, '\\multicolumn{2}{c}{ }');   % NaN
	  end
	else
	  % print nothing, kill \cdot       
	  fprintf(tabout, '\\multicolumn{2}{c}{ }');
	end
    end

    % ampersand or return
    if j < ncols,
      fprintf(tabout, ' & ');
    else
      fprintf(tabout, ' \\\\');
      if isfield(tab(r), 'hline'),
        if ~isempty(tab(r).hline),
	  fprintf(tabout, '\\hline\n');
	else
	  fprintf(tabout, '\n');
	end
      else
	fprintf(tabout, '\n');
      end
    end
	
  end
end

% table closing
fprintf(tabout, '  \\hline\\hline\n');
fprintf(tabout, '\\end{tabular}%%\n%%\n');
fprintf(tabout, '}  %% End of generated table.\n\n');

fclose(tabout);

return
