function tex_table(tabfile, tab),

%    tex_table(tabfile, tab)
%
%  creates a LaTeX-File containing a table presenting matrix data
%
%  tabfile     output file, '.tex' is appended
%  tab         struct array, one struct per column
%                tab(j).header    string with table head, math
%                      .format    'int', 'fix', 'sci', 'string'
%                      .digits    (mantissa) digits right of dec.pt.
%                      .data      vector with column data
%
%  The LaTeX created requires class diss.

%   Copyright (C) 2001 Hans Ekkehard Plesser
%
%   This program is free software; you can redistribute it and/or
%   modify it under the terms of the GNU General Public License
%   as published by the Free Software Foundation; either version 2
%   of the License, or (at your option) any later version.
%
%   This program is distributed in the hope that it will be useful,
%   but WITHOUT ANY WARRANTY; without even the implied warranty of
%   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%   GNU General Public License for more details.
%
%   You should have received a copy of the GNU General Public License
%   along with this program; if not, write to the Free Software
%   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

% get number of columns and rows
ncols = length(tab);
nrows = -1;
for j = 1:ncols,
  switch tab(j).format,
    case 'string',
      nrows = max([size(tab(j).data, 1) nrows]);
    otherwise,
      nrows = max([length(tab(j).data) nrows]);
  end
end

% open file and write tabular header
tabout = fopen([tabfile '.tex'], 'w');

% set tabular parameters, encapsule table in {}
fprintf(tabout, '{%%  Table generated by tex_table.m\n%%\n');
fprintf(tabout, '\\setlength{\\extrarowheight}{2pt}\n');
fprintf(tabout, '\\setlength{\\arrayrulewidth}{0.4pt}\n');
fprintf(tabout, '\\setlength{\\doublerulesep}{0pt}\n');
fprintf(tabout, '\\setlength{\\tabcolsep}{10pt}\n');
fprintf(tabout, '\\renewcommand{\\arraystretch}{1.05}\n%%\n');

fprintf(tabout, '\\begin{tabular}{');
for j = 1:ncols,
  switch tab(j).format
    case 'int'
      fprintf(tabout, 'R');      % integers aligned right, math mode
    case 'fix'
      fprintf(tabout, 'D{.}{.}{%d}', tab(j).digits); % fix, math mode
    case 'sci'
      fprintf(tabout, 'D{.}{.}{%d}@{$\\cdot$}L', tab(j).digits);
               % mantissa fix, central dot, exponent
    case 'string'	       
      fprintf(tabout, 'l');      % strings, left aligned
    otherwise
      fclose(tabout);	       
      error(['Unknown format: ' tab(j).format ' !']);
  end
  
  % vertical line between columns
%  if j < ncols,
%    fprintf(tabout, '|');
%  end
end
fprintf(tabout, '}\n');

% header line of table, centered, math mode
fprintf(tabout, '  \\hline\\hline\n');
for j = 1:ncols,
  if 0, % j < ncols
    fmt = 'C|';
  else
    fmt = 'C';
  end
  
  switch tab(j).format
    case {'int', 'fix', 'string'}
      fprintf(tabout, '  \\multicolumn{1}{%s}{%s}', fmt, tab(j).header);
    case 'sci'
      fprintf(tabout, '  \\multicolumn{2}{%s}{%s}', fmt, tab(j).header);
  end
  
  % ampersand or return
  if j < ncols,
    fprintf(tabout, ' &\n');
  else
    fprintf(tabout, ' \\\\\\hline\n');
  end
end
    
% table data
for r = 1:nrows,
  for j = 1:ncols,
    switch tab(j).format
      case 'int'
	if r <= length(tab(j).data),
	  if isfinite(tab(j).data(r)),
	    fprintf(tabout, '%10.0f', fix(tab(j).data(r)));
	  elseif isinf(tab(j).data(r)),
	    if tab(j).data(r) > 0,
	      fprintf(tabout, '\\multicolumn{1}{C}{+\\infty}');
	    else
	      fprintf(tabout, '\\multicolumn{1}{C}{-\\infty}');
	    end
	  else
	    fprintf(tabout, '%10s', ' ');      % NAN
	  end
	else
	  fprintf(tabout, '%10s', ' ');
	end
      case 'fix'
	if r <= length(tab(j).data),
	  if isfinite(tab(j).data(r)),
	    fprintf(tabout, ['%10.' num2str(tab(j).digits) 'f'], ...
		            tab(j).data(r));
	  elseif isinf(tab(j).data(r)),
	    if tab(j).data(r) > 0,
	      fprintf(tabout, '\\multicolumn{1}{C}{+\\infty}');
	    else
	      fprintf(tabout, '\\multicolumn{1}{C}{-\\infty}');
	    end
	  else
	    fprintf(tabout, '%10s', ' ');      % NAN
	  end
	else
	  fprintf(tabout, '%10s', ' ');
	end
      case 'sci'
	if r <= length(tab(j).data),
	  if isfinite(tab(j).data(r)),
	    ex   = floor(log10(tab(j).data(r)));
	    mant = tab(j).data(r) / 10^ex;
	    fprintf(tabout, ...
	                  ['%10.' num2str(tab(j).digits) 'f & 10^{%-2d}'], ...
	                  mant, ex);
	  elseif isinf(tab(j).data(r)),
	    if tab(j).data(r) > 0,
	      fprintf(tabout, '\\multicolumn{2}{C}{+\\infty}');
	    else
	      fprintf(tabout, '\\multicolumn{2}{C}{-\\infty}');
	    end
	  else
	    fprintf(tabout, '\\multicolumn{2}{c}{ }');   % NaN
	  end
	else
	  % print nothing, kill \cdot       
	  fprintf(tabout, '\\multicolumn{2}{c}{ }');
	end
      case 'string',
	if r <= size(tab(j).data, 1),
	  fprintf(tabout, '%10s', deblank(tab(j).data(r, :)));
	else
          fprintf(tabout, '%10s', ' ');
	end
    end

    % ampersand or return
    if j < ncols,
      fprintf(tabout, ' & ');
    else
      fprintf(tabout, ' \\\\');
      if 0, % r < nrows,
	fprintf(tabout, '\\hline\n');
      else
	fprintf(tabout, '\n');
      end
    end
	
  end
end

% table closing
fprintf(tabout, '  \\hline\\hline\n');
fprintf(tabout, '\\end{tabular}%%\n%%\n');
fprintf(tabout, '}  %% End of generated table.\n\n');

fclose(tabout);

return
